
.. =========
.. Thinkings
.. =========


Deep Learning
=============

.. toctree::
    :maxdepth: 1

    deep_learning/from_qualitative_to_quantitative
    deep_learning/dl_system_perspective_zh
    deep_learning/dl_system_perspective_en
    deep_learning/what_did_the_success_of_dl_prove
    deep_learning/why_dl_so_effective


Artificial Intelligence
=======================

.. toctree::
    :maxdepth: 1

    artificial_intelligence/the_real_ai_in_my_mind
    artificial_intelligence/ai_question_is_a_philosophical_question
    artificial_intelligence/how_nlp_understands_semantics


Systems Theory
==============

.. toctree::
    :maxdepth: 1

    systems_theory/the_essence_of_the_world


Cognitive Science
=================

.. toctree::
    :maxdepth: 1

    cognitive_science/further_exploration_of_my_research_direction
    cognitive_science/preliminary_discussion_of_my_research_direction


